const gulp = require("gulp");
const uglify = require("gulp-uglify");
const cleanCss = require("gulp-clean-css");
const replace = require("gulp-string-replace");
const del = require("del");

function clean() {
    return del(["addon", "keymap", "lib", "mode", "theme"]);
}

function jsmin() {
    return gulp.src(["CodeMirror/addon/**/*.js", "CodeMirror/mode/**/*.js", "CodeMirror/keymap/*.js", "CodeMirror/lib/codemirror.js", "!CodeMirror/**/*test.js"], {
            base: "CodeMirror"
        })
        .pipe(uglify())
        .pipe(gulp.dest("."));
}

function cssmin() {
    return gulp.src(["CodeMirror/addon/**/*.css", "CodeMirror/theme/*.css", "CodeMirror/lib/codemirror.css"], {
            base: "CodeMirror"
        })
        .pipe(cleanCss())
        .pipe(gulp.dest("."));
}

function translate() {
    return gulp.src(["keymap/vim.js"])
        // showConfirm
        .pipe(replace("Not an editor command ", "未找到命令"))
        .pipe(replace("Invalid mapping", "无效映射"))
        .pipe(replace("No such mapping", "无此映射"))
        .pipe(replace("Regular Expression missing from global", "全局缺少正则表达式"))
        .pipe(replace("Invalid regex", "无效的正则表达式"))
        .pipe(replace("No matches for", "未匹配到"))
        .pipe(replace("Substitutions should be of the form", "替换的形式应为"))
        .pipe(replace("Argument required", "缺少参数"))
        .pipe(replace(/Invalid arguments?/, "无效的参数"))
        .pipe(replace("No previous substitute regular expression", "在此之前无正则表达式"))
        // throw Error
        .pipe(replace("defaultValue is required unless callback is provided", "除非提供回调，否则需要默认值"))
        .pipe(replace("Register name must be 1 character", "寄存器名称必须为1个字符"))
        .pipe(replace("Register already defined", "寄存器已定义"))
        .pipe(replace("Mode not supported for ex mappings", "不支持ex映射模式"))
        .pipe(replace("Trailing characters", "尾随字符"))
        // 其他
        .pipe(replace("replace with", "替换"))
        .pipe(replace("Javascript regexp", "正则表达式"))
        .pipe(replace("searching", "正在搜索"))
        .pipe(gulp.dest("keymap"));
}

exports.default = gulp.series(clean, jsmin, cssmin, translate);